@@ -1,4 +1,4 @@
-# Copyright (c) 2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 2004-2006 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -8,13 +8,24 @@ use strict;
 use vars qw($VERSION @Plugins);
 use Carp;
 
-$VERSION = "2.07";
+$VERSION = "2.11";
 
 @Plugins = qw(
 	Authen::SASL::Cyrus
 	Authen::SASL::Perl
 );
 
+
+sub import {
+  shift;
+  return unless @_;
+
+  local $SIG{__DIE__};
+  @Plugins = grep { /^[:\w]+$/ and eval "require $_" } map { /::/ ? $_ : "Authen::SASL::$_" } @_
+    or croak "no valid Authen::SASL plugins found";
+}
+
+
 sub new {
   my $pkg = shift;
   my %opt = ((@_ % 2 ? 'mechanism' : ()), @_);
@@ -22,6 +33,7 @@ sub new {
   my $self = bless {
     mechanism => $opt{mechanism} || $opt{mech},
     callback  => {},
+    debug => $opt{debug},
   }, $pkg;
 
   $self->callback(%{$opt{callback}}) if ref($opt{callback}) eq 'HASH';
@@ -78,6 +90,11 @@ sub server_new { # $self, $service, $host, $secflags
   croak "Cannot find a SASL Connection library for server-side authentication";
 }
 
+sub error {
+  my $self = shift;
+  $self->{conn} && $self->{conn}->error;
+}
+
 # Compat.
 sub user {
   my $self = shift;
